@@ -221,7 +221,10 @@ class ModelArtifact(Introspectable):
 
         if create:
             self.progress = progress
-            self._generate_runtime_yaml(model_file_name=model_file_name)
+            if "CONDA_PREFIX" in os.environ and "NB_SESSION_OCID" in os.environ:
+                self._generate_runtime_yaml(model_file_name=model_file_name)
+            else:
+                self._generate_empty_runtime_yaml(model_file_name=model_file_name)
             self.version = MODEL_ARTIFACT_VERSION
 
         # This will re-install the env which the model artifact was trained in.
@@ -375,8 +378,6 @@ class ModelArtifact(Introspectable):
     def _generate_runtime_yaml(self, model_file_name="model.onnx"):
         if self.progress:
             self.progress.update("Creating runtime.yaml configuration")
-        if "CONDA_PREFIX" not in os.environ or "NB_SESSION_OCID" not in os.environ:
-            self._generate_empty_runtime_yaml(model_file_name=model_file_name)
 
         ns = self.__fetch_runtime_schema__()
         training_env_info = self.__fetch_training_env_details(ns.TrainingCondaEnv())
