@@ -16,14 +16,12 @@ from urllib.parse import urlparse
 from pathlib import Path
 from pandas import DataFrame
 from ast import literal_eval
-import logging
 
-from IPython.display import display, HTML
+from IPython.display import display
 from jinja2 import Environment, PackageLoader
 
-from ads.common import oci_client, auth
+from ads.common import oci_client, auth, logger
 
-import oci
 from oci.data_flow.models import (
     CreateApplicationDetails,
     Application,
@@ -35,7 +33,6 @@ from oci.data_flow.models import (
     UpdateRunDetails,
     RunSummary,
 )
-from oci.config import from_file
 from oci.exceptions import ServiceError
 
 from ads.common import utils
@@ -53,6 +50,11 @@ update_run_details_attributes = UpdateRunDetails().swagger_types.keys()
 run_attributes = list(Run().swagger_types.keys())
 
 
+class SPARK_VERSION(str):
+    v2_4_4 = "2.4.4"
+    v3_0_2 = "3.0.2"
+
+
 class DataFlow:
     def __init__(
         self,
@@ -96,7 +98,7 @@ class DataFlow:
             )
         )
         if not self.region:
-            logging.warning(
+            logger.warning(
                 "Region information not found from oci config file. Please set region in the OCI config file"
             )
         try:
@@ -170,6 +172,7 @@ class DataFlow:
         display_name: str,
         script_bucket: str,
         pyspark_file_path: str,
+        spark_version: str = SPARK_VERSION.v2_4_4,
         compartment_id: str = None,
         archive_path: str = None,
         archive_bucket: str = None,
@@ -267,10 +270,7 @@ class DataFlow:
 
         # when user try to specify a non-python application, we throw warnings
         if self.language is not None and self.language != "PYTHON":
-            utils.print_user_message(
-                "ADS only supports python applications.",
-                display_type="warning",
-            )
+            logger.warning("ADS only supports Python.")
 
         app_compartment_id = (
             self.compartment_id if compartment_id is None else compartment_id
@@ -288,7 +288,7 @@ class DataFlow:
             "driver_shape": self.driver_shape,
             "executor_shape": self.executor_shape,
             "num_executors": self.num_executors,
-            "spark_version": "2.4.4",
+            "spark_version": spark_version,
         }
 
         # here we handle the case where users specify arguments
@@ -308,13 +308,12 @@ class DataFlow:
                         )
 
                     if arg_name not in script_parameters:
-                        utils.print_user_message(
-                            f"With <code>{arg}</code> in the format of "
-                            "<code>${var}</code>, "
-                            f"the argument <code>{arg_name}</code> will be replaced by the value provided in script parameters when passed in, "
-                            f"while arguments not in this format are passed into the pyspark script verbatim.\n"
-                            f"Therefore, <code>{arg_name}</code> must be a valid key in script parameters.",
-                            display_type="warning",
+                        logger.warning(
+                            f"With `{arg}` in the format of "
+                            "`${var}`, "
+                            f"the argument `{arg_name}` will be replaced by the value provided in script parameters when passed in. "
+                            f"While arguments not in this format are passed to the PySpark script verbatim."
+                            f"Therefore, `{arg_name}` must be a valid key in script parameters."
                         )
                         raise KeyError(
                             f"{arg_name} doesn't exist in script parameters, thus {arg} is not valid."
@@ -367,9 +366,7 @@ class DataFlow:
         script_path = os.path.join(file_dir, file_name)
 
         if os.path.exists(script_path):
-            utils.print_user_message(
-                f"The <code>{file_name}</code> already exists in <code>{file_dir}</code> and will be overwritten."
-            )
+            logger.info(f"Overwriting {script_path}.")
 
         if job_type == "standard_pyspark":
             self._get_pyspark_template(script_path, script_str)
@@ -382,7 +379,7 @@ class DataFlow:
         relative_path = os.path.relpath(script_path)
         # FileLink has to be tested with router to check compatibility. Till then let us comment it (ODSC-8310)
         # return display(FileLink(relative_path))
-        utils.print_user_message(f"Code generated: {script_path}")
+        logger.info(f"Code generated: {script_path}.")
         return script_path
 
     def _get_pyspark_template(self, script_path, script_str: str = ""):
@@ -670,24 +667,19 @@ class DataFlow:
         object_name = os.path.basename(local_path)
         if self._check_object_exist(object_name, bucket_name):
             if not overwrite:
-                utils.print_user_message(
-                    "You have a file with the same key in your bucket on object storage.",
-                    display_type="warning",
-                )
                 raise ValueError(
                     "You have a file with the same key in your bucket on object storage. Please rename your file or set overwrite option to True."
                 )
             else:
-                utils.print_user_message(
-                    "You have a file with the same key in your bucket on object storage. It will be overwritten per your request.",
-                    display_type="warning",
+                logger.warning(
+                    "You have a file with the same key in your bucket on object storage. It will be overwritten per your request."
                 )
 
         with open(local_path, "rb") as in_file:
             self.object_storage_client.put_object(
                 self.namespace, bucket_name, object_name, in_file
             )
-            utils.print_user_message(f"Finished uploading <code>{object_name}</code>.")
+            logger.info(f"Finished uploading `{object_name}`.")
 
     def _check_object_exist(self, object_name: str, bucket_name: str) -> bool:
         """
@@ -708,14 +700,14 @@ class DataFlow:
         )
 
         if object_exist:
-            utils.print_user_message(
-                f"The file object <code>{object_name}</code> "
-                f"already exists in bucket <code>{bucket_name}</code>."
+            logger.info(
+                f"The file object `{object_name}` "
+                f"already exists in bucket `{bucket_name}`."
             )
         else:
-            utils.print_user_message(
-                f"The file object <code>{object_name}</code> "
-                f"does not exist in bucket <code>{bucket_name}</code> and will be uploaded."
+            logger.info(
+                f"The file object `{object_name}` "
+                f"does not exist in bucket `{bucket_name}` and will be uploaded."
             )
         return object_exist
 
@@ -789,7 +781,7 @@ class DataFlow:
 
         # handle empty list
         if list_applications_response is None:
-            utils.print_user_message("No applications found.", display_type="warning")
+            logger.warning("No applications found.")
             return
 
         application_list_filtered = [
@@ -874,18 +866,14 @@ class DataFlow:
 
         # if users try to load a non-python application, we throw a warning
         if get_app_response.data.language != "PYTHON":
-            utils.print_user_message(
-                "ADS currently only support python applications.",
-                display_type="warning",
-            )
+            logger.warning("ADS only supports Python.")
             return
 
         # for apps created with default logs bucket, logs_bucket_uri attribute in app response will be empty string
         # set default value manually for logs_bucket
         if get_app_response.data.logs_bucket_uri == "":
-            utils.print_user_message(
-                "The loaded application will use the default logs bucket 'dataflow-logs'.",
-                display_type="warning",
+            logger.info(
+                "Using the default logs bucket 'dataflow-logs'. Set the parameter `logs_bucket_uri` to use a different bucket."
             )
             logs_bucket = "dataflow-logs"
         else:
@@ -904,7 +892,7 @@ class DataFlow:
             "executor_shape": get_app_response.data.executor_shape,
             "num_executors": get_app_response.data.num_executors,
             "spark_version": get_app_response.data.spark_version,
-            "arguments": [param.name for param in get_app_response.data.parameters],
+            "arguments": get_app_response.data.arguments,
             "script_parameters": [
                 (param.name, param.value) for param in get_app_response.data.parameters
             ],
@@ -1023,7 +1011,7 @@ class DataFlowApp(DataFlow):
         Returns
         -------
         oci_link: str
-            link to the app page in an oci console.
+            a link to the app page in an oci console.
         """
         return self._oci_link
 
@@ -1248,10 +1236,10 @@ class DataFlowApp(DataFlow):
                     os_objectname,
                     in_file,
                 )
-                utils.print_user_message(
-                    f"The existing file <code>{os_objectname}</code> in bucket "
-                    f"<code>{os_bucket}</code> on object storage has been overwritten by your latest changes of "
-                    f"<code>{os_objectname}</code>."
+                logger.info(
+                    f"The existing file `{os_objectname}` in bucket "
+                    f"`{os_bucket}` on object storage has been overwritten by your latest changes of "
+                    f"`{os_objectname}`."
                 )
             except ServiceError as se:
                 if se.status == 404:
@@ -1289,10 +1277,10 @@ class DataFlowApp(DataFlow):
         except ServiceError as se:
             if se.code == "ObjectNotFound":
                 local_filename = os.path.basename(file_path)
-                utils.print_user_message(
-                    f"The <code>{local_filename}</code> is "
+                logger.info(
+                    f"The `{local_filename}` is "
                     f"not found in your bucket. "
-                    f"The <code>{local_filename}</code> will be uploaded"
+                    f"The `{local_filename}` will be uploaded"
                 )
 
                 with open(file_path, "rb") as in_file:
@@ -1342,7 +1330,7 @@ class DataFlowApp(DataFlow):
 
         # handle empty list
         if list_runs_response is None:
-            utils.print_user_message("No runs found.", display_type="warning")
+            logger.warning("No runs found.")
             return
 
         run_list_filtered = [
@@ -1731,8 +1719,8 @@ class DataFlowRun(DataFlow):
 
     def _repr_html_(self):
         if self.status == "FAILED":
-            utils.print_user_message("This run failed.", display_type="warning")
-            utils.print_user_message("Printing tail of the stdout log...")
+            logger.warning("Run failed. See the logs for details.")
+            logger.info("Printing tail of the stdout log...")
             self.log_stdout.tail()
         else:
             return
@@ -1824,10 +1812,9 @@ class DataFlowLog:
             Path of the log file in local directory
         """
         if self._local_path is None:
-            utils.print_user_message(
+            logger.warning(
                 "The log file is not stored in local directory. "
                 "Please call the save() method to save the log file to local first.",
-                display_type="warning",
             )
 
         return self._local_path
@@ -1863,16 +1850,13 @@ class DataFlowLog:
         None
         """
         if self._local_path is not None:
-            utils.print_user_message(
-                f"The log file is already saved in <code>{self._local_path}</code>",
-                display_type="warning",
-            )
+            logger.warning(f"The log file is already exists in `{self._local_path}`.")
             return
         if log_dir is not None:
             self._local_dir = log_dir
 
         if not os.path.isdir(self._local_dir):
-            os.mkdir(self._local_dir)
+            os.makedirs(self._local_dir)
 
         filename = os.path.basename(self._oci_path)
         self._local_path = os.path.join(self._local_dir, filename)
@@ -1880,9 +1864,7 @@ class DataFlowLog:
         with open(self._local_path, "w+") as in_file:
             in_file.write(self.text)
 
-        utils.print_user_message(
-            f"The log file is now saved in <code>{self._local_path}</code>"
-        )
+        logger.info(f"The log file saved to `{self._local_path}`.")
 
     def __str__(self):
         return self.text
@@ -1906,4 +1888,4 @@ class DataFlowLog:
         relative_path = os.path.relpath(self._local_path)
         # FileLink has to be tested with router to check compatibility. Till then let us comment it (ODSC-8310)
         # return display(FileLink(relative_path))
-        return utils.print_user_message(f"Log file location: {self._local_path}")
+        return logger.info(f"Log file saved to {self._local_path}.")
