@@ -9,15 +9,18 @@ from ads.type_discovery.typed_feature import DateTimeTypedFeature
 
 
 class ForecastingDataset(ADSDatasetWithTarget):
-
     def __init__(self, ddf, sampled_df, target, target_type, shape, **kwargs):
         # index on target
         if isinstance(target, DateTimeTypedFeature):
             ddf = ddf.set_index(target)
-        ADSDatasetWithTarget.__init__(self, ddf, sampled_df, target, target_type, shape, **kwargs)
+        ADSDatasetWithTarget.__init__(
+            self, ddf, sampled_df, target, target_type, shape, **kwargs
+        )
 
     def select_best_features(self, score_func=None, k=12):
         """
         Not yet implemented
         """
-        raise NotImplementedError("Feature selection for forecasting dataset is not yet supported")
+        raise NotImplementedError(
+            "Feature selection for forecasting dataset is not yet supported"
+        )
