@@ -13,7 +13,7 @@ from ads.common import oci_client
 
 class OCILanguage(object):  # pragma: no cover
     def __init__(self, auth=None):
-        auth = auth if auth else authutil.api_keys()
+        auth = auth if auth else authutil.default_signer()
         self.ai_client = oci_client.OCIClientFactory(**auth).ai_language
 
     @property
@@ -55,3 +55,11 @@ class OCILanguage(object):  # pragma: no cover
             detect_language_sentiments_details
         )
         return json.loads(str(output.data))["aspects"]
+
+    @property
+    def text_classification(self):
+        detect_language_text_clf_details = (
+            oci.ai_language.models.DetectLanguageTextClassificationDetails(text=self.string)
+        )
+        output = self.ai_client.detect_language_text_classification(detect_language_text_clf_details)
+        return json.loads(str(output.data))["text_classification"]
