@@ -1,17 +1,29 @@
 #!/usr/bin/env python
 # -*- coding: utf-8; -*-
 
+# Copyright (c) 2021 Oracle and/or its affiliates.
+# Licensed under the Universal Permissive License v 1.0 as shown at https://oss.oracle.com/licenses/upl/
+"""Utilities used by the model deployment package
+"""
+
+# Standard lib
+import fsspec
+import json
 # Copyright (c) 2021 Oracle and/or its affiliates.
 # Licensed under the Universal Permissive License v 1.0 as shown at https://oss.oracle.com/licenses/upl/
 
 import logging
 import oci
 import os
+import shutil
 import sys
+import tempfile
 import time
 import yaml
+from typing import Dict
 
 from enum import Enum, auto
+from oci.data_science.models import CreateModelDetails
 from oci.signer import Signer
 from oci.util import get_signer_from_authentication_type, AUTHENTICATION_TYPE_FIELD_NAME
 from .progress_bar import TqdmProgressBar, DummyProgressBar
@@ -336,3 +348,76 @@ class OCIClientManager:
         oci_config, signer = OCIClientManager.get_oci_config_signer(config)
         return oci_config.get("compartment_id") or oci_config.get("tenancy") or \
                getattr(signer, "tenancy_id", None)
+
+
+    @staticmethod
+    def _prepare_artifact(model_uri: str, properties: Dict, ds_client=None) -> str:
+        """
+        Prepare model artifact. Returns model ocid.
+
+        Args:
+            model_uri (str): uri to model files, can be local or in cloud storage
+            properties (dict): dictionary of properties that are needed for creating a model.
+            ds_client (DataScienceClient): OCI DataScienceClient
+
+        Returns:
+            str: model ocid
+        """
+        if not ds_client:
+            ds_client = OCIClientManager.oci_ds_client()
+        if properties:
+            properties_dict = (
+                properties
+                if isinstance(properties, dict)
+                else json.loads(repr(properties))
+            )
+        with tempfile.TemporaryDirectory() as d:
+            fhandlers = fsspec.open_files(
+                model_uri,
+                config=OCIClientManager.get_oci_config(),
+                mode="rb",
+            )
+            if len(fhandlers) == 0:
+                raise FileNotFoundError("No files found under this path.")
+            for fh in fhandlers:
+                with fh as fin:
+                    with open(os.path.join(d, os.path.basename(fh.path)), "wb") as fout:
+                        fout.write(fin.read())
+            shutil.make_archive(
+                os.path.join(os.path.dirname(d), "model_files"),
+                "zip",
+                os.path.dirname(d),
+                os.path.basename(d),
+            )
+            return OCIClientManager._upload_artifact(
+                ds_client,
+                f"{os.path.join(os.path.dirname(d), 'model_files')}.zip",
+                properties_dict,
+            )
+
+    @staticmethod
+    def _upload_artifact(ds_client, model_zip: str, properties: dict) -> str:
+        """Uploads the model artifact to cloud storage.
+
+        Args:
+            ds_client (DataScienceClient): OCI DataScienceClient
+            model_zip (str): path to model artifact zip file
+            properties (dict): dictionary of properties
+
+        Returns:
+            str: model ocid
+        """
+        create_model_details = CreateModelDetails(
+            display_name=properties.get("display_name", None),
+            project_id=properties["project_id"],
+            compartment_id=properties["compartment_id"],
+        )
+
+        model = ds_client.create_model(create_model_details).data
+        with open(model_zip, "rb") as data:
+            ds_client.create_model_artifact(
+                model.id,
+                data,
+                content_disposition=f'attachment; filename="{model.id}.zip"',
+            )
+        return model.id
