@@ -46,6 +46,23 @@ Usage:
     >> deployer.list_deployments() # Optionally pass in a status
 """
 
+# Standard library
+import os
+import json
+from typing import Union, Dict
+
+# Third party
+import pandas as pd
+
+# Oracle
+from .common import utils
+from .common.utils import OCIClientManager, State
+import oci
+
+from .model_deployment import ModelDeployment, DEFAULT_WAIT_TIME, DEFAULT_POLL_INTERVAL
+from .model_deployment_properties import ModelDeploymentProperties
+
+
 class ModelDeployer:
     """ModelDeployer is the class responsible for deploying the ModelDeployment
 
@@ -83,8 +100,6 @@ class ModelDeployer:
                 which can be a dictionary or the path of YAML containing the config.
                 If None, default config will be used.
 
-        Configurations
-        --------------
         The following keys can be used in the config:
         auth: Authentication method, must be either "resource_principal" or "api_key".
             If auth is not specified:
@@ -104,11 +119,11 @@ class ModelDeployer:
 
     def deploy(
         self,
-        properties=None,
+        properties: Union[ModelDeploymentProperties, Dict] = None,
         wait_for_completion: bool = True,
         max_wait_time: int = DEFAULT_WAIT_TIME,
         poll_interval: int = DEFAULT_POLL_INTERVAL,
-        **kwargs
+        **kwargs,
     ) -> ModelDeployment:
         """Deploys a model.
 
@@ -129,12 +144,57 @@ class ModelDeployer:
             config=self.config,
             ds_client=self.ds_client,
             ds_composite_client=self.ds_composite_client,
-            **kwargs
+            **kwargs,
         )
         return model_deployment.deploy(
             wait_for_completion, max_wait_time, poll_interval
         )
 
+    def deploy_from_model_uri(
+        self,
+        model_uri: str,
+        properties: Union[ModelDeploymentProperties, Dict] = None,
+        wait_for_completion: bool = True,
+        max_wait_time: int = DEFAULT_WAIT_TIME,
+        poll_interval: int = DEFAULT_POLL_INTERVAL,
+        **kwargs,
+    ) -> ModelDeployment:
+        """Deploys a model.
+
+        Args:
+            model_uri (str): uri to model files, can be local or in cloud storage
+            properties (ModelDeploymentProperties or dict): properties to deploy the model.
+                properties can be None when kwargs are used for specifying properties.
+            wait_for_completion (bool, optional): Flag set for whether to wait for deployment to complete before
+                proceeding. Defaults to True
+            max_wait_time (int, optional): Maximum amount of time to wait in seconds (Defaults to 1200). Negative implies infinite wait time.
+            poll_interval (int, optional): Poll interval in seconds (Defaults to 30).
+            kwargs: Keyword arguments for initializing ModelDeploymentProperties
+
+        Returns:
+            ModelDeployment: ModelDeployment object that was deployed
+        """
+        if properties:
+            model_id = OCIClientManager._prepare_artifact(
+                model_uri=model_uri, properties=properties, ds_client=self.ds_client
+            )
+            properties.model_deployment_configuration_details.model_configuration_details.model_id = (
+                model_id
+            )
+        else:
+            model_id = OCIClientManager._prepare_artifact(
+                model_uri=model_uri, properties=kwargs, ds_client=self.ds_client
+            )
+            kwargs["model_id"] = model_id
+
+        return self.deploy(
+            properties,
+            wait_for_completion=wait_for_completion,
+            max_wait_time=max_wait_time,
+            poll_interval=poll_interval,
+            **kwargs,
+        )
+
     def update(
         self,
         model_deployment_id: str,
@@ -142,7 +202,7 @@ class ModelDeployer:
         wait_for_completion: bool = True,
         max_wait_time: int = DEFAULT_WAIT_TIME,
         poll_interval: int = DEFAULT_POLL_INTERVAL,
-        **kwargs
+        **kwargs,
     ) -> ModelDeployment:
         """Updates an existing model deployment.
 
@@ -168,7 +228,7 @@ class ModelDeployer:
             wait_for_completion,
             max_wait_time=max_wait_time,
             poll_interval=poll_interval,
-            **kwargs
+            **kwargs,
         )
 
     def get_model_deployment(self, model_deployment_id: str) -> ModelDeployment:
@@ -276,6 +336,7 @@ class ModelDeployer:
         deployments = oci.pagination.list_call_get_all_results(
             self.ds_client.list_model_deployments, compartment_id, **kwargs
         ).data
+
         return [ModelDeployment(deployment) for deployment in deployments]
 
     def show_deployments(
