@@ -149,14 +149,14 @@ class ModelDeployment:
         Raises:
             Exception: raised on deployment errors during _wait_for_activation
         """
-
         response = self.ds_composite_client.create_model_deployment_and_wait_for_state(
-            self.properties.to_create_deployment()
+            self.properties.build()
         )
         self.workflow_req_id = response.headers["opc-work-request-id"]
         res_payload = json.loads(str(response.data))
         self.current_state = State._from_str(res_payload["lifecycle_state"])
         self.model_deployment_id = res_payload["id"]
+        self.url = res_payload["model_deployment_url"]
         if wait_for_completion:
             try:
                 self._wait_for_activation(max_wait_time, poll_interval)
