@@ -5,16 +5,28 @@
 # Licensed under the Universal Permissive License v 1.0 as shown at https://oss.oracle.com/licenses/upl/
 
 import oci.data_science.models as data_science_models
+import os
+import tempfile
+import shutil
+import fsspec
+
+from .common import utils
+from .common.utils import OCIClientManager
+
+from ads.common.oci_datascience import OCIDataScienceMixin
 from typing import Any, Optional, Union
 
 
-class ModelDeploymentProperties(data_science_models.ModelDeployment):
+class ModelDeploymentProperties(
+    OCIDataScienceMixin, data_science_models.ModelDeployment
+):
     """Represents the details for a model deployment
 
     Attributes
     ----------
     swagger_types (dict): The property names and the corresponding types of OCI ModelDeployment model.
-    model_id (str): the model artifact OCID in model catelog.
+    model_id (str): the model artifact OCID in model catalog
+    model_uri (str): uri to model files, can be local or in cloud storage
 
     Methods
     -------
@@ -44,6 +56,7 @@ class ModelDeploymentProperties(data_science_models.ModelDeployment):
     def __init__(
         self,
         model_id: Optional[str] = None,
+        model_uri: Optional[str] = None,
         oci_model_deployment: Union[
             data_science_models.ModelDeployment,
             data_science_models.CreateModelDeploymentDetails,
@@ -58,6 +71,7 @@ class ModelDeploymentProperties(data_science_models.ModelDeployment):
 
         Args:
             model_id (str): Model Artifact OCID
+            model_uri (str): uri to model files, can be local or in cloud storage
             oci_model_deployment: An OCI model or dict containing model deployment details.
                 The OCI model can be an instance of either ModelDeployment, CreateModelDeploymentDetails or
                 UpdateModelConfigurationDetails.
@@ -86,6 +100,9 @@ class ModelDeploymentProperties(data_science_models.ModelDeployment):
             oci_model_deployment.model_deployment_configuration_details.model_configuration_details
         """
         self.model_id = model_id
+        self.model_uri = model_uri
+        self.config = utils.load_config()
+        self.ds_client = OCIClientManager.oci_ds_client(self.config)
         oci_kwargs = {}
         if oci_model_deployment:
             # User specified oci_model_deployment, which could be an OCI model object or a dict
@@ -294,83 +311,24 @@ class ModelDeploymentProperties(data_science_models.ModelDeployment):
         return self
 
     def build(self):
-        """Converts the deployment properties to OCI CreateModelDeploymentDetails object."""
-        return self.to_create_deployment()
-
-    def to_oci_model(self):
-        """Coverts the deployment properties to OCI ModelDeployment object."""
-        oci_model = data_science_models.ModelDeployment()
-        for attr in self.swagger_types.keys():
-            val = getattr(self, attr)
-            setattr(oci_model, attr, val)
-        return oci_model
-
-    def to_create_deployment(self):
-        """Converts the deployment properties to OCI CreateModelDeploymentDetails object."""
-        create_details = data_science_models.CreateModelDeploymentDetails()
-        self.copy_attributes(self.to_oci_model(), create_details)
-
-        # Check the required parameters when creating a deployment
-        if not self.model_id:
-            raise ValueError("model_id is required when creating a deployment.")
-        if not self.model_deployment_configuration_details:
-            raise ValueError(
-                "Instance configuration is required when creating a deployment."
-                "Please use with_instance_configuration() to specify instance_count and instance shape."
+        """Converts the deployment properties to OCI CreateModelDeploymentDetails object.
+        Converts a model URI into a model OCID if user passed in a URI.
+        """
+        if self.model_uri:
+            self.model_id = OCIClientManager._prepare_artifact(
+                model_uri=self.model_uri,
+                properties=dict(
+                    display_name="testing",
+                    project_id=self.project_id,
+                    compartment_id=self.compartment_id,
+                ),
+                ds_client=self.ds_client,
             )
-        model_config = (
-            create_details.model_deployment_configuration_details.model_configuration_details
-        )
-        if (
-            not model_config.instance_configuration
-            or not model_config.instance_configuration.instance_shape_name
-        ):
-            raise ValueError("instance_shape is required when creating a deployment.")
-        if (
-            not model_config.scaling_policy
-            or not model_config.scaling_policy.instance_count
-        ):
-            raise ValueError("instance_count is required when creating a deployment.")
-        return create_details
+            self.model_deployment_configuration_details.model_configuration_details.model_id = (
+                self.model_id
+            )
+        return self.to_oci_model(data_science_models.CreateModelDeploymentDetails)
 
     def to_update_deployment(self):
         """Converts the deployment properties to OCI UpdateModelDeploymentDetails object."""
-        update_details = data_science_models.UpdateModelDeploymentDetails()
-        self.copy_attributes(self.to_oci_model(), update_details)
-        return update_details
-
-    @staticmethod
-    def copy_attributes(from_obj, to_obj):
-        """Copies the attribute from an instance of OCI model to another.
-
-        Args:
-            from_obj: An instance of OCI model with the attributes to be copied from.
-            to_obj: An instance of OCI model to which the attributes will be copied.
-
-        Returns:
-            An instance of OCI model with attributes copied.
-        """
-        # Maps the ModelDeploymentConfigurationDetails to the corresponding SingleModelDeploymentConfigurationDetails
-        # The OCI API returns internal error if we use ModelDeploymentConfigurationDetails directly.
-        class_mapping = {
-            "ModelDeploymentConfigurationDetails": "SingleModelDeploymentConfigurationDetails",
-            "UpdateModelDeploymentConfigurationDetails": "UpdateSingleModelDeploymentConfigurationDetails",
-        }
-        for attr, to_attr_type in to_obj.swagger_types.items():
-            if hasattr(from_obj, attr):
-                value = getattr(from_obj, attr)
-                if not value:
-                    continue
-                from_attr_type = from_obj.swagger_types[attr]
-                if from_attr_type == to_attr_type:
-                    setattr(to_obj, attr, value)
-                else:
-                    if to_attr_type in class_mapping:
-                        to_attr_type = class_mapping[to_attr_type]
-                    model_class = getattr(data_science_models, to_attr_type)
-                    setattr(
-                        to_obj,
-                        attr,
-                        ModelDeploymentProperties.copy_attributes(value, model_class()),
-                    )
-        return to_obj
+        return self.to_oci_model(data_science_models.UpdateModelDeploymentDetails)
