@@ -54,17 +54,6 @@ class FileProcessor:
             raise NotSupportedError(
                 f"backend {backend} is not recognized or not a subclass of ads.text_dataset.backends.Base."
             )
-        if isinstance(self._backend, Tika) and (
-            "CONDA_PREFIX" not in os.environ
-            or not os.path.exists(
-                os.path.join(
-                    os.environ.get("CONDA_PREFIX"), "text-extraction-tools.jar"
-                )
-            )
-        ):
-            raise NotSupportedError(
-                "Tika is not supported in this distribution. Please use alternatives such as pdfplumber."
-            )
         return self
 
     def read_line(
