@@ -17,20 +17,32 @@ from ads.type_discovery.typed_feature import ZipcodeTypedFeature
 
 
 class ZipCodeDetector(AbstractTypeDiscoveryDetector):
-
     def _is_zip_code(self, values):
-        return all([re.match("^[0-9]{5}(?:-[0-9]{4})?$", str(v)) for v in values.head(10)])
+        return all(
+            [re.match("^[0-9]{5}(?:-[0-9]{4})?$", str(v)) for v in values.head(10)]
+        )
 
     def discover(self, name, series):
         candidates = series.loc[~series.isnull()]
-        if self._is_zip_code(candidates.head(1000)) if candidates.dtype == 'object' else self._is_zip_code(
-                candidates.astype('object')):
-            logger.debug("type discovery on column [{}]/[{}] found to be a zipcode".format(name, series.dtype))
+        if (
+            self._is_zip_code(candidates.head(1000))
+            if candidates.dtype == "object"
+            else self._is_zip_code(candidates.astype("object"))
+        ):
+            logger.debug(
+                "type discovery on column [{}]/[{}] found to be a zipcode".format(
+                    name, series.dtype
+                )
+            )
             return ZipcodeTypedFeature.build(name, series)
 
         return False
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     dd = ZipCodeDetector()
-    print(dd.discover("zip", pd.Series([None, "00501", "94065", "94065-1107", "90210", None])))
+    print(
+        dd.discover(
+            "zip", pd.Series([None, "00501", "94065", "94065-1107", "90210", None])
+        )
+    )
